==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/BuildConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BuildConditionBuilder extends io.fabric8.openshift.api.model.BuildConditionFluentImpl<io.fabric8.openshift.api.model.BuildConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.BuildCondition,io.fabric8.openshift.api.model.BuildConditionBuilder>{
  public BuildConditionBuilder() {
    this(false);
  }
  public BuildConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new BuildCondition(), validationEnabled);
  }
  public BuildConditionBuilder(io.fabric8.openshift.api.model.BuildConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildConditionBuilder(io.fabric8.openshift.api.model.BuildConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BuildCondition(), validationEnabled);
  }
  public BuildConditionBuilder(io.fabric8.openshift.api.model.BuildConditionFluent<?> fluent,io.fabric8.openshift.api.model.BuildCondition instance) {
    this(fluent, instance, false);
  }
  public BuildConditionBuilder(io.fabric8.openshift.api.model.BuildConditionFluent<?> fluent,io.fabric8.openshift.api.model.BuildCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BuildConditionBuilder(io.fabric8.openshift.api.model.BuildCondition instance) {
    this(instance,false);
  }
  public BuildConditionBuilder(io.fabric8.openshift.api.model.BuildCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.BuildConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.BuildCondition build() {
    BuildCondition buildable = new BuildCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildConditionBuilder that = (BuildConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.6.0-sources.jar: io/fabric8/openshift/api/model/BuildConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BuildConditionBuilder extends BuildConditionFluentImpl<BuildConditionBuilder> implements VisitableBuilder<BuildCondition,BuildConditionBuilder>{
  public BuildConditionBuilder() {
    this(false);
  }
  public BuildConditionBuilder(Boolean validationEnabled) {
    this(new BuildCondition(), validationEnabled);
  }
  public BuildConditionBuilder(BuildConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildConditionBuilder(BuildConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BuildCondition(), validationEnabled);
  }
  public BuildConditionBuilder(BuildConditionFluent<?> fluent,BuildCondition instance) {
    this(fluent, instance, false);
  }
  public BuildConditionBuilder(BuildConditionFluent<?> fluent,BuildCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BuildConditionBuilder(BuildCondition instance) {
    this(instance,false);
  }
  public BuildConditionBuilder(BuildCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  BuildConditionFluent<?> fluent;
  Boolean validationEnabled;
  public BuildCondition build() {
    BuildCondition buildable = new BuildCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
